@@ -175,10 +175,10 @@ class Tool(object):
         if data:
             df = pd.DataFrame(data)
             statistics = df.describe(include='all')
-            # add row with total for numeric columns
+            # append row with total for each numeric column
             sums = df.sum(numeric_only=True)
             sums.name = 'total'
-            statistics = statistics.append(sums)
+            statistics = pd.concat([statistics, sums.to_frame().T])
             # update the aggregate entry of outputs (item 0)
             self._aggregate['outputs'][0].update(clean_dict(unflatten_dict(statistics.to_dict())))
 
